@@ -22,10 +22,12 @@ EXECUTOR_IMPORTS: Dict[str, ExecutorImport] = {
 def run(
     executor: Union[str, Executor],
     pipeline: Pipeline,
+    pipeline_root: Optional[str] = None,
     **kwargs,
 ):
     if isinstance(executor, str):
         _import = EXECUTOR_IMPORTS[executor]
         executor = getattr(import_module(_import.module), _import.name)()
         assert isinstance(executor, Executor)
-    return executor.run(pipeline, **kwargs)
+
+    return executor.run(pipeline, pipeline_root=pipeline_root, **kwargs)
